@@ -1,6 +1,8 @@
 `design.dau` <-
-function (trt1, trt2, r,number=1,seed=0,kinds="Super-Duper",name="trt")
+function (trt1, trt2, r,serie=2,seed=0,kinds="Super-Duper",name="trt")
 {
+number<-10
+if(serie>0) number<-10^serie
 ntr1 <- length(trt1)
 if(seed != 0) set.seed(seed,kinds)
 mtr1 <- sample(trt1, ntr1, replace = FALSE)
@@ -15,8 +17,10 @@ s<-s<-1:ntr2%%r
 for(i in 1:ntr2) if(s[i]==0)s[i]<-r
 block <- c(block, s)
 mtr <- c(mtr1,mtr2)
-plots <- number+1:(ntr1*r + ntr2)-1
-
+nr<-as.numeric(table(block))
+nt<-length(nr)
+plots<-NULL
+for(i in 1:nt) plots<-c(plots,i*number+1:nr[i])
 book<-data.frame(block=as.factor(block),trt=as.factor(mtr))
 book<-book[order(book[,1]),]
 for (i in 1:r)
